// src/contacts-v4-attachment-attachments.public.ts
import { renameKeysFromRESTResponseToSDKResponse as renameKeysFromRESTResponseToSDKResponse2 } from "@wix/sdk-runtime/rename-all-nested-keys";
import { transformRESTDocumentToSDKDocument as transformRESTDocumentToSDKDocument2 } from "@wix/sdk-runtime/transformations/document";
import { transformRESTImageToSDKImage as transformRESTImageToSDKImage2 } from "@wix/sdk-runtime/transformations/image";
import { transformRESTTimestampToSDKTimestamp as transformRESTTimestampToSDKTimestamp2 } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths as transformPaths3 } from "@wix/sdk-runtime/transformations/transform-paths";
import { EventDefinition } from "@wix/sdk-types";

// src/contacts-v4-attachment-attachments.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/contacts-v4-attachment-attachments.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/contacts-attachments-app",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    _: [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_crm_attachments";
function generateAttachmentUploadUrl(payload) {
  function __generateAttachmentUploadUrl({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "POST",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GenerateAttachmentUploadUrl",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        {
          protoPath: "/v4/attachments/{contactId}/upload-url",
          data: payload,
          host
        }
      ),
      data: payload
    };
    return metadata;
  }
  return __generateAttachmentUploadUrl;
}
function listAttachments(payload) {
  function __listAttachments({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "GET",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.ListAttachments",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        { protoPath: "/v4/attachments/{contactId}", data: payload, host }
      ),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "attachments.image.urlExpirationDate" },
            { path: "attachments.document.urlExpirationDate" },
            { path: "attachments.previewImage.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listAttachments;
}
function deleteAttachment(payload) {
  function __deleteAttachment({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "DELETE",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.DeleteAttachment",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        {
          protoPath: "/v4/attachments/{contactId}/{attachmentId}",
          data: payload,
          host
        }
      ),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteAttachment;
}
function getAttachment(payload) {
  function __getAttachment({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "GET",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GetAttachment",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        {
          protoPath: "/v4/attachments/{contactId}/{attachmentId}",
          data: payload,
          host
        }
      ),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "attachment.image.urlExpirationDate" },
            { path: "attachment.document.urlExpirationDate" },
            { path: "attachment.previewImage.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getAttachment;
}

// src/contacts-v4-attachment-attachments.universal.ts
import { transformRESTImageToSDKImage } from "@wix/sdk-runtime/transformations/image";
import { transformRESTDocumentToSDKDocument } from "@wix/sdk-runtime/transformations/document";
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var AttachmentType = /* @__PURE__ */ ((AttachmentType2) => {
  AttachmentType2["UNKNOWN"] = "UNKNOWN";
  AttachmentType2["IMAGE"] = "IMAGE";
  AttachmentType2["OTHER"] = "OTHER";
  return AttachmentType2;
})(AttachmentType || {});
var CrmAttachmentAttachmentType = /* @__PURE__ */ ((CrmAttachmentAttachmentType2) => {
  CrmAttachmentAttachmentType2["UNKNOWN"] = "UNKNOWN";
  CrmAttachmentAttachmentType2["DOCUMENT"] = "DOCUMENT";
  CrmAttachmentAttachmentType2["IMAGE"] = "IMAGE";
  return CrmAttachmentAttachmentType2;
})(CrmAttachmentAttachmentType || {});
var DemoContactType = /* @__PURE__ */ ((DemoContactType2) => {
  DemoContactType2["KAT"] = "KAT";
  DemoContactType2["DAN"] = "DAN";
  return DemoContactType2;
})(DemoContactType || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function generateAttachmentUploadUrl2(contactId, fileName, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    contactId,
    fileName,
    mimeType: options?.mimeType
  });
  const reqOpts = generateAttachmentUploadUrl(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          contactId: "$[0]",
          fileName: "$[1]",
          mimeType: "$[2].mimeType"
        },
        singleArgumentUnchanged: false
      },
      ["contactId", "fileName", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function listAttachments2(contactId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    contactId,
    paging: options?.paging
  });
  const reqOpts = listAttachments(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "attachments.image" },
            { path: "attachments.previewImage" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [{ path: "attachments.document" }]
        }
      ])
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { contactId: "$[0]", paging: "$[1].paging" },
        singleArgumentUnchanged: false
      },
      ["contactId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function deleteAttachment2(identifiers) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    contactId: identifiers?.contactId,
    attachmentId: identifiers?.attachmentId
  });
  const reqOpts = deleteAttachment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          contactId: "$[0].contactId",
          attachmentId: "$[0].attachmentId"
        },
        singleArgumentUnchanged: false
      },
      ["identifiers"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getAttachment2(identifiers) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    contactId: identifiers?.contactId,
    attachmentId: identifiers?.attachmentId
  });
  const reqOpts = getAttachment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "attachment.image" },
            { path: "attachment.previewImage" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [{ path: "attachment.document" }]
        }
      ])
    )?.attachment;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          contactId: "$[0].contactId",
          attachmentId: "$[0].attachmentId"
        },
        singleArgumentUnchanged: false
      },
      ["identifiers"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/contacts-v4-attachment-attachments.public.ts
function generateAttachmentUploadUrl3(httpClient) {
  return (contactId, fileName, options) => generateAttachmentUploadUrl2(
    contactId,
    fileName,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function listAttachments3(httpClient) {
  return (contactId, options) => listAttachments2(
    contactId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function deleteAttachment3(httpClient) {
  return (identifiers) => deleteAttachment2(
    identifiers,
    // @ts-ignore
    { httpClient }
  );
}
function getAttachment3(httpClient) {
  return (identifiers) => getAttachment2(
    identifiers,
    // @ts-ignore
    { httpClient }
  );
}
var onAttachmentCreated = EventDefinition(
  "wix.contacts.v4.attachment_created",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [{ path: "entity.image" }, { path: "entity.previewImage" }]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [{ path: "entity.document" }]
      },
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [{ path: "metadata.eventTime" }]
      }
    ])
  )
)();
var onAttachmentDeleted = EventDefinition(
  "wix.contacts.v4.attachment_deleted",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "undefined.image" },
          { path: "undefined.previewImage" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [{ path: "undefined.document" }]
      },
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [{ path: "metadata.eventTime" }]
      }
    ])
  )
)();

// src/contacts-v4-attachment-attachments.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
import { createEventModule } from "@wix/sdk-runtime/event-definition-modules";
var generateAttachmentUploadUrl4 = /* @__PURE__ */ createRESTModule(generateAttachmentUploadUrl3);
var listAttachments4 = /* @__PURE__ */ createRESTModule(listAttachments3);
var deleteAttachment4 = /* @__PURE__ */ createRESTModule(deleteAttachment3);
var getAttachment4 = /* @__PURE__ */ createRESTModule(getAttachment3);
var onAttachmentCreated2 = createEventModule(onAttachmentCreated);
var onAttachmentDeleted2 = createEventModule(onAttachmentDeleted);
export {
  AttachmentType,
  CrmAttachmentAttachmentType,
  DemoContactType,
  WebhookIdentityType,
  deleteAttachment4 as deleteAttachment,
  generateAttachmentUploadUrl4 as generateAttachmentUploadUrl,
  getAttachment4 as getAttachment,
  listAttachments4 as listAttachments,
  onAttachmentCreated2 as onAttachmentCreated,
  onAttachmentDeleted2 as onAttachmentDeleted
};
//# sourceMappingURL=index.mjs.map