// src/contacts-v4-attachment-attachments.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/contacts-attachments-app",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    _: [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/contacts/v4/attachments",
        destPath: "/v4/attachments"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_crm_attachments";
function generateAttachmentUploadUrl(payload) {
  function __generateAttachmentUploadUrl({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "POST",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GenerateAttachmentUploadUrl",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        {
          protoPath: "/v4/attachments/{contactId}/upload-url",
          data: payload,
          host
        }
      ),
      data: payload
    };
    return metadata;
  }
  return __generateAttachmentUploadUrl;
}
function listAttachments(payload) {
  function __listAttachments({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "GET",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.ListAttachments",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        { protoPath: "/v4/attachments/{contactId}", data: payload, host }
      ),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "attachments.image.urlExpirationDate" },
            { path: "attachments.document.urlExpirationDate" },
            { path: "attachments.previewImage.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listAttachments;
}
function deleteAttachment(payload) {
  function __deleteAttachment({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "DELETE",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.DeleteAttachment",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        {
          protoPath: "/v4/attachments/{contactId}/{attachmentId}",
          data: payload,
          host
        }
      ),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteAttachment;
}
function getAttachment(payload) {
  function __getAttachment({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.attachment",
      method: "GET",
      methodFqn: "com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GetAttachment",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(
        {
          protoPath: "/v4/attachments/{contactId}/{attachmentId}",
          data: payload,
          host
        }
      ),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "attachment.image.urlExpirationDate" },
            { path: "attachment.document.urlExpirationDate" },
            { path: "attachment.previewImage.urlExpirationDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getAttachment;
}

// src/contacts-v4-attachment-attachments.meta.ts
function generateAttachmentUploadUrl2() {
  const payload = { contactId: ":contactId" };
  const getRequestOptions = generateAttachmentUploadUrl(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v4/attachments/{contactId}/upload-url",
    pathParams: { contactId: "contactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function listAttachments2() {
  const payload = { contactId: ":contactId" };
  const getRequestOptions = listAttachments(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v4/attachments/{contactId}",
    pathParams: { contactId: "contactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteAttachment2() {
  const payload = {
    contactId: ":contactId",
    attachmentId: ":attachmentId"
  };
  const getRequestOptions = deleteAttachment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v4/attachments/{contactId}/{attachmentId}",
    pathParams: { contactId: "contactId", attachmentId: "attachmentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getAttachment2() {
  const payload = {
    contactId: ":contactId",
    attachmentId: ":attachmentId"
  };
  const getRequestOptions = getAttachment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v4/attachments/{contactId}/{attachmentId}",
    pathParams: { contactId: "contactId", attachmentId: "attachmentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  deleteAttachment2 as deleteAttachment,
  generateAttachmentUploadUrl2 as generateAttachmentUploadUrl,
  getAttachment2 as getAttachment,
  listAttachments2 as listAttachments
};
//# sourceMappingURL=meta.mjs.map