import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { G as GenerateAttachmentUploadUrlOptions, a as GenerateAttachmentUploadUrlResponse, L as ListAttachmentsOptions, b as ListAttachmentsResponse, D as DeleteAttachmentIdentifiers, c as GetAttachmentIdentifiers, C as ContactAttachment, A as AttachmentCreatedEnvelope, d as AttachmentDeletedEnvelope } from './contacts-v4-attachment-attachments.universal-D9hQ5kaw.mjs';
export { m as ActionEvent, s as AttachmentMedia, t as AttachmentMediaMediaOneOf, r as AttachmentMetadata, q as AttachmentSource, e as AttachmentType, K as BaseEventMetadata, h as ContactAttachmentMediaOneOf, u as CreateDemoAttachmentRequest, v as CreateDemoAttachmentResponse, p as CrmAttachment, f as CrmAttachmentAttachmentType, o as CrmAttachmentUploadedEvent, z as DeleteAttachmentRequest, B as DeleteAttachmentResponse, g as DemoContactType, i as DomainEvent, j as DomainEventBodyOneOf, n as Empty, E as EntityCreatedEvent, l as EntityDeletedEvent, k as EntityUpdatedEvent, N as EventMetadata, w as GenerateAttachmentUploadUrlRequest, F as GetAttachmentRequest, H as GetAttachmentResponse, I as IdentificationData, J as IdentificationDataIdOneOf, x as ListAttachmentsRequest, M as MessageEnvelope, P as Paging, y as PagingMetadata, R as RestoreInfo, W as WebhookIdentityType } from './contacts-v4-attachment-attachments.universal-D9hQ5kaw.mjs';

declare function generateAttachmentUploadUrl$1(httpClient: HttpClient): GenerateAttachmentUploadUrlSignature;
interface GenerateAttachmentUploadUrlSignature {
    /**
     * Generates an upload URL for uploading a file as an attachment to a specified contact.
     *
     * To learn how to use the generated upload URL in the response to upload an attachment file,
     * see the Upload API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/media/files/upload-api) | [REST](https://dev.wix.com/docs/rest/assets/media/media-manager/files/upload-api)).
     * @param - ID of the contact for whom the attachment is being uploaded.
     * @param - File name of the attachment including the extension, for example, `contact-cv.pdf`.
     */
    (contactId: string, fileName: string, options: GenerateAttachmentUploadUrlOptions): Promise<GenerateAttachmentUploadUrlResponse>;
}
declare function listAttachments$1(httpClient: HttpClient): ListAttachmentsSignature;
interface ListAttachmentsSignature {
    /**
     * Retrieves a list of attachments associated with a specified contact.
     * @param - Contact ID for the attachments to be listed.
     */
    (contactId: string, options?: ListAttachmentsOptions | undefined): Promise<ListAttachmentsResponse>;
}
declare function deleteAttachment$1(httpClient: HttpClient): DeleteAttachmentSignature;
interface DeleteAttachmentSignature {
    /**
     * Deletes the specified attachment from the specified contact.
     */
    (identifiers: DeleteAttachmentIdentifiers): Promise<void>;
}
declare function getAttachment$1(httpClient: HttpClient): GetAttachmentSignature;
interface GetAttachmentSignature {
    /**
     * Retrieves the specified attachment for the specified contact.
     * @returns The requested attachment.
     */
    (identifiers: GetAttachmentIdentifiers): Promise<ContactAttachment>;
}
declare const onAttachmentCreated$1: EventDefinition<AttachmentCreatedEnvelope, "wix.contacts.v4.attachment_created">;
declare const onAttachmentDeleted$1: EventDefinition<AttachmentDeletedEnvelope, "wix.contacts.v4.attachment_deleted">;

declare const generateAttachmentUploadUrl: MaybeContext<BuildRESTFunction<typeof generateAttachmentUploadUrl$1> & typeof generateAttachmentUploadUrl$1>;
declare const listAttachments: MaybeContext<BuildRESTFunction<typeof listAttachments$1> & typeof listAttachments$1>;
declare const deleteAttachment: MaybeContext<BuildRESTFunction<typeof deleteAttachment$1> & typeof deleteAttachment$1>;
declare const getAttachment: MaybeContext<BuildRESTFunction<typeof getAttachment$1> & typeof getAttachment$1>;
/** */
declare const onAttachmentCreated: BuildEventDefinition<typeof onAttachmentCreated$1>;
/** */
declare const onAttachmentDeleted: BuildEventDefinition<typeof onAttachmentDeleted$1>;

export { AttachmentCreatedEnvelope, AttachmentDeletedEnvelope, ContactAttachment, DeleteAttachmentIdentifiers, GenerateAttachmentUploadUrlOptions, GenerateAttachmentUploadUrlResponse, GetAttachmentIdentifiers, ListAttachmentsOptions, ListAttachmentsResponse, deleteAttachment, generateAttachmentUploadUrl, getAttachment, listAttachments, onAttachmentCreated, onAttachmentDeleted };
