import { w as GenerateAttachmentUploadUrlRequest$1, a as GenerateAttachmentUploadUrlResponse$1, x as ListAttachmentsRequest$1, b as ListAttachmentsResponse$1, z as DeleteAttachmentRequest$1, B as DeleteAttachmentResponse$1, F as GetAttachmentRequest$1, H as GetAttachmentResponse$1 } from './contacts-v4-attachment-attachments.universal-D9hQ5kaw.mjs';

interface ContactAttachment extends ContactAttachmentMediaOneOf {
    /** Image details when the attachment type is `IMAGE`. */
    image?: Image;
    /** Document details when the attachment type is `OTHER`. */
    document?: Document;
    /**
     * Attachment ID.
     * @readonly
     * @format GUID
     */
    id?: string;
    /**
     * Details of the preview image reduced size when the attachment is of type `IMAGE`.
     * @readonly
     */
    previewImage?: Image;
    /**
     * Name of the attachment file.
     * @readonly
     */
    fileName?: string;
    /**
     * Mime type of the attachment. See supported mime types
     * ([REST](https://dev.wix.com/docs/rest/crm/members-contacts/contacts/attachments/attachment-v4/supported-mime-types)|[SDK](https://dev.wix.com/docs/sdk/backend-modules/crm/attachments/supported-mime-types)).
     * @readonly
     */
    mimeType?: string;
    /**
     * Type of the attachment.
     * @readonly
     */
    attachmentType?: AttachmentTypeWithLiterals;
}
/** @oneof */
interface ContactAttachmentMediaOneOf {
    /** Image details when the attachment type is `IMAGE`. */
    image?: Image;
    /** Document details when the attachment type is `OTHER`. */
    document?: Document;
}
interface Image {
    /** WixMedia image ID. */
    id?: string;
    /** Image URL. */
    url?: string;
    /**
     * Original image height.
     * @readonly
     */
    height?: number;
    /**
     * Original image width.
     * @readonly
     */
    width?: number;
    /** Image alt text. Optional. */
    altText?: string | null;
    /**
     * Image URL expiration date when relevant.
     * @readonly
     */
    urlExpirationDate?: Date | null;
}
interface Document {
    /** WixMedia ID. */
    id?: string;
    /** Document URL. */
    url?: string;
    /**
     * Document URL expiration date when relevant.
     * @readonly
     */
    urlExpirationDate?: Date | null;
}
declare enum AttachmentType {
    /** Unknown attachment type. */
    UNKNOWN = "UNKNOWN",
    /** Attachment is an image file. */
    IMAGE = "IMAGE",
    /** Attachment is a document or any non-image file type. */
    OTHER = "OTHER"
}
/** @enumType */
type AttachmentTypeWithLiterals = AttachmentType | 'UNKNOWN' | 'IMAGE' | 'OTHER';
interface GenerateAttachmentUploadUrlRequest {
    /**
     * ID of the contact for whom the attachment is being uploaded.
     * @format GUID
     */
    contactId: string;
    /**
     * File name of the attachment including the extension, for example, `contact-cv.pdf`.
     * @minLength 1
     * @maxLength 260
     */
    fileName: string;
    /**
     * Mime type of the attachment file, for example, `application/pdf`.
     * See supported mime types ([REST](https://dev.wix.com/docs/rest/crm/members-contacts/contacts/attachments/attachment-v4/supported-mime-types)|
     * [SDK](https://dev.wix.com/docs/sdk/backend-modules/crm/attachments/supported-mime-types)).
     * @minLength 1
     * @maxLength 255
     */
    mimeType: string;
}
interface GenerateAttachmentUploadUrlResponse {
    /**
     * The URL for uploading a file as an attachment to the contact.
     * @format WEB_URL
     */
    uploadUrl?: string;
}
interface ListAttachmentsRequest {
    /**
     * Contact ID for the attachments to be listed.
     * @format GUID
     */
    contactId: string;
    /** Allow paginating, default: limit = 100 and offset = 0 */
    paging?: Paging;
}
interface Paging {
    /**
     * Number of items to return.
     *
     * Default: `100`
     * Max: `100`
     * @max 100
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface ListAttachmentsResponse {
    /** List of attachments for the specified contact. */
    attachments?: ContactAttachment[];
    /** Metadata for the paginated results. */
    metadata?: PagingMetadata;
}
interface PagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. */
    total?: number | null;
    /** Whether the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
}
interface DeleteAttachmentRequest {
    /**
     * Contact ID for the attachment to delete.
     * @format GUID
     */
    contactId: string;
    /**
     * Attachment ID to delete.
     * @format GUID
     */
    attachmentId: string;
}
interface DeleteAttachmentResponse {
}
interface GetAttachmentRequest {
    /**
     * Contact ID for the attachment to retrieve.
     * @format GUID
     */
    contactId: string;
    /**
     * Attachment ID to retrieve.
     * @format GUID
     */
    attachmentId: string;
}
interface GetAttachmentResponse {
    /** The requested attachment. */
    attachment?: ContactAttachment;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function generateAttachmentUploadUrl(): __PublicMethodMetaInfo<'POST', {
    contactId: string;
}, GenerateAttachmentUploadUrlRequest$1, GenerateAttachmentUploadUrlRequest, GenerateAttachmentUploadUrlResponse$1, GenerateAttachmentUploadUrlResponse>;
declare function listAttachments(): __PublicMethodMetaInfo<'GET', {
    contactId: string;
}, ListAttachmentsRequest$1, ListAttachmentsRequest, ListAttachmentsResponse$1, ListAttachmentsResponse>;
declare function deleteAttachment(): __PublicMethodMetaInfo<'DELETE', {
    contactId: string;
    attachmentId: string;
}, DeleteAttachmentRequest$1, DeleteAttachmentRequest, DeleteAttachmentResponse$1, DeleteAttachmentResponse>;
declare function getAttachment(): __PublicMethodMetaInfo<'GET', {
    contactId: string;
    attachmentId: string;
}, GetAttachmentRequest$1, GetAttachmentRequest, GetAttachmentResponse$1, GetAttachmentResponse>;

export { type __PublicMethodMetaInfo, deleteAttachment, generateAttachmentUploadUrl, getAttachment, listAttachments };
